using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using Microsoft.SharePoint;

namespace EventHandlerSequence
{
    public class Sequence : SPItemEventReceiver
    {
        const string c_logFileFolder = @"c:\temp";        
        string LogFileName = "Sequence.htm";
        LogEvent log;

        public Sequence()
        {
            log = new LogEvent(c_logFileFolder, LogFileName, true, false);
        }
        public override void ItemAdded(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemAdded");
        }
        public override void ItemAdding(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemAdding");

        }
        public override void ItemAttachmentAdded(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemAttachmentAdded");
        }
        public override void ItemAttachmentAdding(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemAttachmentAdding");
        }
        public override void ItemAttachmentDeleted(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemAttachmentDeleted");
        }
        public override void ItemAttachmentDeleting(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemAttachmentDeleting");
        }
        public override void ItemCheckedIn(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemCheckedIn");
        }
        public override void ItemCheckedOut(SPItemEventProperties properties)
        {            
            log.WriteEvent("ItemCheckedOut");
        }
        public override void ItemUpdating(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemUpdating");
        }
        public override void ItemUpdated(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemUpdated");
        }
        public override void ItemCheckingIn(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemCheckingIn");
        }
        public override void ItemCheckingOut(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemCheckingOut");
        }
        public override void ItemDeleted(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemDeleted");
        }
        public override void ItemDeleting(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemDeleting");
        }
        public override void ItemFileConverted(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemFileConverted");
        }
        public override void ItemFileMoved(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemFileMoved");
        }
        public override void ItemFileMoving(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemFileMoving");
        }
        public override void ItemUncheckedOut(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemUncheckedOut");
        }
        public override void ItemUncheckingOut(SPItemEventProperties properties)
        {
            log.WriteEvent("ItemUncheckingOut");
        }        

    }
    class LogEvent
    {

        private string _LogFolderPath = @"c:\logs";
        public string LogFolderPath
        {
            get
            {
                return _LogFolderPath;
            }
            set
            {
                if (Directory.Exists(value))
                {
                    _LogFolderPath = value;
                    if (_LogFolderPath.EndsWith("\\"))
                    {
                        _LogFolderPath = _LogFolderPath.Remove(_LogFolderPath.Length);
                    }
                }
                else
                {
                    throw new DirectoryNotFoundException();
                }
            }
        }
        private string _LogFileName = "";
        public string LogFileName
        {
            get
            {
                return _LogFileName;
            }
            set
            {
                _LogFileName = value;
            }
        }
        public string LogFilePath
        {
            get
            {
                return this.LogFolderPath + "\\" + this.LogFileName;
            }
        }


        public LogEvent(string folderPath, string fileName, bool createPath, bool deleteFile)
        {
            this.LogFileName = fileName;

            if (createPath && !Directory.Exists(folderPath))
            {
                Directory.CreateDirectory(folderPath);
            }
            this.LogFolderPath = folderPath;
            if (File.Exists(this.LogFilePath) && deleteFile)
            {
                File.Delete(this.LogFilePath);
            }
        }
        public void WriteEvent(string message)
        {

            using (StreamWriter sw = new StreamWriter(this.LogFilePath, true))
            {
                sw.WriteLine("<p>");
                sw.WriteLine("Date:" + DateTime.Now.ToLongTimeString() + "<br />" + message);
                sw.WriteLine("</p>");
                sw.Flush();
            }

        }



    }
}
